/*
This program has been developed by students from the bachelor Computer Science at Utrecht University within the Software Project course.
© Copyright Utrecht University (Department of Information and Computing Sciences)
*/

package rpcdriver

import (
	"context"
	"query-service/internal/drivers/rpcdriver/databaseInfoService"
	"query-service/internal/entity"
	"query-service/pkg/logger"

	"google.golang.org/grpc"
)

/*
GetDatabaseInfo opens a gRPC connection to the user management service and retrieves the database info for the given client and database name
	clientID: *string, the ID of the client,
	databaseName: *string, the name of the database,
	Return: (*entiry.databaseInfo, error), the information of the database and a potential error
*/
func (driver *Driver) GetDatabaseInfo(clientID *string, databaseName *string) (*entity.DatabaseInfo, error) {
	conn, err := grpc.Dial("user-management-service:9000", grpc.WithInsecure())
	if err != nil {
		return nil, err
	}
	defer conn.Close()

	grpcClient := databaseInfoService.NewDatabaseInfoServiceClient(conn)

	logger.Log("getting database info for client " + *clientID + " for database " + *databaseName)

	response, err := grpcClient.GetDatabaseInfo(context.Background(), &databaseInfoService.DatabaseInfoRequest{ClientID: *clientID, DatabaseName: *databaseName})
	if err != nil {
		return nil, err
	}

	return &entity.DatabaseInfo{
		URL:                  response.Url,
		Port:                 int(response.Port),
		Username:             response.Username,
		Password:             response.Password,
		InternalDatabaseName: response.InternalDatabaseName,
	}, nil
}
